diff --git a/examples/comments/README.md b/examples/comments/README.md
index f1fea96f..bb167a30 100644
--- a/examples/comments/README.md
+++ b/examples/comments/README.md
@@ -25,11 +25,11 @@ A list of comment threads. **Note:** More about comment threads [**here**](./Com
### applySort(sort)
-Sorts the comments with the given sort type.
+Applies given sort option to the comments.
| Param | Type | Description |
| --- | --- | --- |
-| sort | `string` | Sort type. Can be `TOP_COMMENTS`, `NEWEST_FIRST` |
+| sort | `string` | Sort option. Can be `TOP_COMMENTS`, `NEWEST_FIRST` |
**Returns:** [`Promise.`](../../src/parser/youtube/Comments.ts)
diff --git a/src/parser/youtube/Comments.ts b/src/parser/youtube/Comments.ts
index 3c766798..b3575ecf 100644
--- a/src/parser/youtube/Comments.ts
+++ b/src/parser/youtube/Comments.ts
@@ -43,12 +43,12 @@ class Comments {
}
/**
* Sorts the comments with the given sort type.
* @param sort - Sort type.
*/
async applySort(sort: 'TOP_COMMENTS' | 'NEWEST_FIRST'): Promise {
if (!this.header)
- throw new InnertubeError('Page header is missing. Cannot apply sort filter.');
+ throw new InnertubeError('Page header is missing. Cannot apply sort option.');
let button;
@@ -43,12 +43,12 @@ class Comments {
}
/**
- * Sorts the comments with the given sort type.
+ * Applies given sort option to the comments.
* @param sort - Sort type.
*/